# Common tools

This project contains a few common tools that I like to use.

Each file has a few functions. 

1. notifications.py - to make notifications during long runs.
2. plotting.py - helping functions for matplotlib and plotly.
3. tools.py - statistical functions and pandas.
- [ ] Create easy plotly_express subplots.
 
- [ ] This is an ongoing project. 


### Installation

pip install git+https://github.com/PTorr/torrs_hammers

pip install -r requirements.txt
